@@ -103,7 +103,6 @@ fn cerror(span: proc_macro2::Span, msg: &str) -> TokenStream {
 /// A post-processed version of `DekuReceiver`
 #[derive(Debug)]
 struct DekuData {
-    vis: syn::Visibility,
     ident: syn::Ident,
     generics: syn::Generics,
     data: ast::Data<VariantData, FieldData>,
@@ -154,7 +153,6 @@ impl DekuData {
         };
 
         let data = Self {
-            vis: receiver.vis,
             ident: receiver.ident,
             generics: receiver.generics,
             data,
@@ -584,7 +582,6 @@ impl VariantData {
 #[derive(Debug, FromDeriveInput)]
 #[darling(attributes(deku), supports(struct_any, enum_any))]
 struct DekuReceiver {
-    vis: syn::Visibility,
     ident: syn::Ident,
     generics: syn::Generics,
     data: ast::Data<DekuVariantReceiver, DekuFieldReceiver>,
